@@ -23,11 +23,12 @@ from typing import AsyncIterable, Optional
 from .attachment import Attachment
 from .data_message import DataMessage
 from .group import Group
+from .groupV2 import GroupV2
 from .message import Message
 from .message_sender import MessageSender
+from .socket import Socket
 from .sticker import Sticker
 from .sticker_pack import StickerPack
-from .socket import Socket
 
 
 class MessageReceiver:
@@ -61,12 +62,17 @@ class MessageReceiver:
                 data = message.get("dataMessage")
                 if data:
                     group: Optional[Group] = None
+                    groupV2: Optional[GroupV2] = None
                     if data.get("group"):
                         group = Group(
                             group_id=data["group"].get("groupId"),
                             name=data["group"].get("name"),
                             group_type=data["group"].get("type"),
                         )
+                    if data.get("groupV2"):
+                        groupV2 = GroupV2(
+                            group_id=data["groupV2"].get("id")
+                        )
 
                     sticker_data = data.get("sticker")
                     sticker: Optional[Sticker] = None
@@ -83,7 +89,7 @@ class MessageReceiver:
                     data_message = DataMessage(
                         timestamp=data["timestamp"],
                         body=data.get("body", ""),
-                        expires_in_seconds=data["expiresInSeconds"],
+                        expires_in_seconds=data.get("expiresInSeconds"),
                         attachments=[
                             Attachment(
                                 content_type=attachment["contentType"],
@@ -96,6 +102,7 @@ class MessageReceiver:
                             for attachment in data.get("attachments", [])
                         ],
                         group=group,
+                        groupV2=groupV2,
                         sticker=sticker,
                     )
 
@@ -105,7 +112,7 @@ class MessageReceiver:
                     envelope_type=message["type"],
                     timestamp=message["timestamp"],
                     timestamp_iso=message["timestampISO"],
-                    server_timestamp=message["serverTimestamp"],
+                    server_timestamp=message["serverDeliveredTimestamp"],
                     source_device=message.get("sourceDevice"),
                     uuid=message.get("uuid"),
                     relay=message.get("relay"),
