@@ -38,8 +38,8 @@ class MessageSender:
         """
         Send the bot message.
 
-        message: The original message replying to.
-        reply:   The reply to send.
+        :param message: The original message replying to.
+        :param reply:   The reply to send.
         """
         # Mark message as read before replying.
         if reply.mark_read:
@@ -77,11 +77,45 @@ class MessageSender:
 
         await self._send(bot_message)
 
+    async def typing_started(self, message: Message) -> None:
+        """
+        Send a typing started message.
+
+        :param message: The Signal message you received.
+        """
+        # Construct reply message.
+        typing_message: Dict[str, Any] = {"type": "typing_started",
+                                          "username": self._username,
+                                          "recipientAddress": {"number": message.source}}
+
+        # Add group id.
+        if message.get_group_id():
+            typing_message["recipientGroupId"] = message.get_group_id()
+
+        await self._send(typing_message)
+
+    async def typing_stopped(self, message: Message) -> None:
+        """
+        Send a typing stopped message.
+
+        :param message: The Signal message you received.
+        """
+        # Construct reply message.
+        typing_message: Dict[str, Any] = {"type": "typing_stopped",
+                                          "username": self._username,
+                                          "recipientAddress": {"number": message.source}}
+
+        # Add group id.
+        if message.get_group_id():
+            typing_message["recipientGroupId"] = message.get_group_id()
+
+        await self._send(typing_message)
+
     async def mark_delivered(self, message: Message) -> None:
         """
         Mark a Signal message you received as delivered.
 
-        message: The Signal message you received.
+        :param message: The Signal message you received.
         """
         await self._send({
             "type": "mark_delivered",
@@ -94,7 +128,7 @@ class MessageSender:
         """
         Mark a Signal message you received as read.
 
-        message: The Signal message you received.
+        :param message: The Signal message you received.
         """
         await self._send({
             "type": "mark_read",
